@@ -3,7 +3,7 @@
 
 package HiD::Page;
 {
-  $HiD::Page::VERSION = '0.3';
+  $HiD::Page::VERSION = '0.4';
 }
 BEGIN {
   $HiD::Page::AUTHORITY = 'cpan:GENEHACK';
@@ -54,11 +54,10 @@ sub _build_url {
   my $naive = join '/' , $path_frag , $self->basename;
 
   my $url;
-  given( $format ) {
-    when( 'none'   ) { $url = $naive . '.html' }
-    when( 'pretty' ) { $url = $naive . '/'     }
-    default          { $url = "/$format"       }
-  }
+
+  if(    $format eq 'none'   ) { $url = $naive . '.html' }
+  elsif( $format eq 'pretty' ) { $url = $naive . '/'     }
+  else                         { $url = "/$format"       }
 
   $url =~ s|//+|/|g;
 
@@ -69,6 +68,7 @@ __PACKAGE__->meta->make_immutable;
 1;
 
 __END__
+
 =pod
 
 =encoding utf-8
@@ -111,7 +111,7 @@ object from this class works.
 
 =head1 VERSION
 
-version 0.3
+version 0.4
 
 =head1 AUTHOR
 
@@ -125,4 +125,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
